@@ -508,6 +508,8 @@ void FGAIBase::bind() {
         SGRawValueMethods<FGAIBase,const char*>(*this,
         &FGAIBase::_getCallsign,
         0));
+    // 2018.2 - to ensure consistent properties also tie the callsign to where it would be in a local model.
+    tie("sim/multiplay/callsign", SGRawValueMethods<FGAIBase, const char*>(*this, &FGAIBase::_getCallsign, 0));
 
     tie("orientation/pitch-deg",   SGRawValuePointer<double>(&pitch));
     tie("orientation/roll-deg",    SGRawValuePointer<double>(&roll));
@@ -526,6 +528,7 @@ void FGAIBase::bind() {
     tie("subID", SGRawValuePointer<int>(&_subID));
     tie("controls/lighting/nav-lights", SGRawValueFunctions<bool>(_isNight));
 
+
     props->setBoolValue("controls/lighting/beacon", true);
     props->setBoolValue("controls/lighting/strobe", true);
     props->setBoolValue("controls/glide-path", true);
