@@ -64,7 +64,7 @@ protected:
         } else if ((aReason == STATUS_REFRESHED) || (aReason == STATUS_SUCCESS)) {
             m_model->refreshPackages();
         } else {
-            qWarning() << "failed refresh of "
+            qWarning() << "failed refresh of"
                 << QString::fromStdString(aCatalog->url()) << ":" << aReason << endl;
         }
 
@@ -179,6 +179,8 @@ AircraftItemModel::AircraftItemModel(QObject* pr) :
             this, &AircraftItemModel::onScanStarted);
     connect(cache, &LocalAircraftCache::addedItems,
             this, &AircraftItemModel::onScanAddedItems);
+    connect(cache, &LocalAircraftCache::cleared,
+            this, &AircraftItemModel::onLocalCacheCleared);
 }
 
 AircraftItemModel::~AircraftItemModel()
@@ -190,7 +192,7 @@ void AircraftItemModel::setPackageRoot(const simgear::pkg::RootRef& root)
 {
     if (m_packageRoot) {
         delete m_delegate;
-        m_delegate = NULL;
+        m_delegate = nullptr;
     }
 
     m_packageRoot = root;
@@ -645,6 +647,17 @@ void AircraftItemModel::onScanAddedItems(int addedCount)
     endInsertRows();
 }
 
+void AircraftItemModel::onLocalCacheCleared()
+{
+    const int firstRow = 0;
+    const int lastRow = m_cachedLocalAircraftCount + 1;
+
+    beginRemoveRows(QModelIndex(), firstRow, lastRow);
+    m_delegateStates.remove(0, m_cachedLocalAircraftCount);
+    m_cachedLocalAircraftCount = 0;
+    endRemoveRows();
+}
+
 void AircraftItemModel::installFailed(QModelIndex index, simgear::pkg::Delegate::StatusCode reason)
 {
     QString msg;
