@@ -262,8 +262,12 @@ void initApp(int& argc, char** argv, bool doInitQSettings)
         // whichever log locations SimGear has configured
         qInstallMessageHandler(simgearMessageOutput);
 
+        // ensure we use desktop OpenGL, don't even fall back to ANGLE, since
+        // this gets into a knot on Optimus setups (since we export the magic
+        // Optimus / AMD symbols in main.cxx).
+        QCoreApplication::setAttribute(Qt::AA_UseDesktopOpenGL);
 #if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
-        // for 2018.1, disable this on @indows, since font-sizing is not
+        // for 2018.2, disable this on Windows, since font-sizing is not
         // behaving consistently across different Windows setups
 #if !defined (Q_OS_WIN)
         QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -397,7 +401,7 @@ bool runLauncherDialog()
         LaunchConfig::setEnableDownloadDirUI(false);
     } else {
         QSettings settings;
-        QString downloadDir = settings.value("downloadSettings/downloadDir").toString();
+        QString downloadDir = settings.value("download-dir").toString();
         if (!downloadDir.isEmpty()) {
             options->setOption("download-dir", downloadDir.toStdString());
         }
