@@ -313,11 +313,21 @@ FGHIDDevice::FGHIDDevice(hid_device_info *devInfo, FGHIDEventInput *)
         productName = std::wstring(devInfo->product_string);
     const auto serial = devInfo->serial_number;
     
-    auto path = devInfo->path;
-    
     SetName(simgear::strutils::convertWStringToUtf8(manufactuerName) + " " +
             simgear::strutils::convertWStringToUtf8(productName));
-    SetSerialNumber(simgear::strutils::convertWStringToUtf8(serial));
+    
+    // every device so far encountered returns a blank serial number, so we
+    // fall back to the device path to disambiguate.
+    std::string path(devInfo->path);
+    if ((serial == nullptr) || std::wcslen(serial) == 0) {
+        // use device path to disambiguate
+        if (!path.empty()) {
+            SG_LOG(SG_INPUT, SG_INFO, "Missing serial on device, using path: " << path);
+            SetSerialNumber(path);
+        }
+    } else {
+        SetSerialNumber(simgear::strutils::convertWStringToUtf8(serial));
+    }
 }
     
 FGHIDDevice::~FGHIDDevice()
@@ -701,8 +711,18 @@ void FGHIDEventInput::init()
     // requires Nasal to be running
 }
 
+void FGHIDEventInput::reinit()
+{
+    SG_LOG(SG_INPUT, SG_INFO, "Re-Initializing HID input bindings");
+    FGHIDEventInput::shutdown();
+    FGHIDEventInput::init();
+    FGHIDEventInput::postinit();
+}
+
 void FGHIDEventInput::postinit()
 {
+    SG_LOG(SG_INPUT, SG_INFO, "HID event input starting up");
+
     hid_init();
     
     hid_device_info* devices = hid_enumerate(0 /* vendor ID */, 0 /* product ID */);
@@ -716,6 +736,7 @@ void FGHIDEventInput::postinit()
 
 void FGHIDEventInput::shutdown()
 {
+    SG_LOG(SG_INPUT, SG_INFO, "HID event input shutting down");
     FGEventInput::shutdown();
     
     hid_exit();
