@@ -704,3 +704,18 @@ bool FGMouseInput::isRightDragToLookEnabled() const
 
     return (d->rightClickModeCycle == false);
 }
+
+bool FGMouseInput::isActiveModePassThrough() const
+{
+    if (!d) {
+        return false;
+    }
+    
+    mouse &m = d->mice[0];
+    int mode = m.current_mode;
+    if (isRightDragToLookEnabled() && m.mouse_button_nodes[2]->getBoolValue()) {
+        mode = 3;
+    }
+    
+    return m.modes[mode].pass_through;
+}
