@@ -22,9 +22,7 @@
 //
 // $Id$
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
+#include <config.h>
 
 #include "input.hxx"
 
@@ -33,7 +31,10 @@
 #include <Main/fg_props.hxx>
 #include "FGMouseInput.hxx"
 #include "FGKeyboardInput.hxx"
+
+#if defined(ENABLE_PLIB_JOYSTICK)
 #include "FGJoystickInput.hxx"
+#endif
 
 #ifdef WITH_EVENTINPUT
 #if defined( SG_WINDOWS )
@@ -48,6 +49,10 @@
 #define INPUTEVENT_CLASS FGLinuxEventInput
 #endif
 
+#if defined(ENABLE_HID_INPUT)
+#include "FGHIDEventInput.hxx"
+#endif
+
 #endif
 
 ////////////////////////////////////////////////////////////////////////
@@ -60,7 +65,7 @@ FGInput::FGInput ()
   if( fgGetBool("/sim/input/no-mouse-input",false) ) {
     SG_LOG(SG_INPUT,SG_ALERT,"Mouse input disabled!");
   } else {
-    set_subsystem( "input-mouse", new FGMouseInput() );
+    set_subsystem( FGMouseInput::subsystemName(), new FGMouseInput() );
   }
 
   if( fgGetBool("/sim/input/no-keyboard-input",false) ) {
@@ -69,11 +74,14 @@ FGInput::FGInput ()
     set_subsystem( "input-keyboard", new FGKeyboardInput() );
   }
 
+#if defined(ENABLE_PLIB_JOYSTICK)
   if( fgGetBool("/sim/input/no-joystick-input",false) ) {
     SG_LOG(SG_INPUT,SG_ALERT,"Joystick input disabled!");
   } else {
     set_subsystem( "input-joystick", new FGJoystickInput() );
   }
+#endif
+
 #ifdef INPUTEVENT_CLASS
   if( fgGetBool("/sim/input/no-event-input",false) ) {
     SG_LOG(SG_INPUT,SG_ALERT,"Event input disabled!");
@@ -81,6 +89,14 @@ FGInput::FGInput ()
     set_subsystem( "input-event", new INPUTEVENT_CLASS() );
   }
 #endif
+    
+#if defined(ENABLE_HID_INPUT) && defined(WITH_EVENTINPUT)
+  if (fgGetBool("/sim/input/no-hid-input", false)) {
+    SG_LOG(SG_INPUT, SG_WARN, "HID-based event input disabled");
+  } else {
+    set_subsystem( "input-event-hid", new FGHIDEventInput() );
+  }
+#endif
 }
 
 FGInput::~FGInput ()
