@@ -1,4 +1,4 @@
-#include "unitTestHelpers.hxx"
+#include "test_suite/helpers/globals.hxx"
 
 #include <simgear/misc/test_macros.hxx>
 
